@@ -8,11 +8,11 @@ Rubric::WebApp - the web interface to Rubric
 
 =head1 VERSION
 
-version 0.145
+version 0.146
 
 =cut
 
-our $VERSION = '0.145';
+our $VERSION = '0.146';
 
 =head1 SYNOPSIS
 
@@ -1002,8 +1002,11 @@ sub _post_form_contents {
     for qw(entryid uri title description tags body);
 
   for (qw(uri title description body tags)) {
-    eval { decode_utf8($form{$_}, Encode::FB_CROAK) };
-    $error{$_} = "Invalid UTF-8 characters in $_." if $@;
+    my $ok = eval {
+      decode_utf8($form{$_}, Encode::FB_CROAK | Encode::LEAVE_SRC);
+      1;
+    };
+    $error{$_} = "Invalid UTF-8 characters in $_." unless $ok;
   }
 
   eval { $form{uri} = URI->new($form{uri})->canonical; };
